@@ -61,7 +61,7 @@ Sample usage:
 
 =head1 COPYRIGHT
 
-Copyright (C) 2012-2014 Igor Afanasyev <igor.afanasyev@gmail.com>
+Copyright (C) 2012-2015 Igor Afanasyev <igor.afanasyev@gmail.com>
 
 =head1 SEE ALSO
 
@@ -71,7 +71,7 @@ L<https://github.com/iafan/Config-Neat>
 
 package Config::Neat;
 
-our $VERSION = '1.101';
+our $VERSION = '1.2';
 
 use strict;
 
@@ -212,6 +212,10 @@ sub parse {
         my $c = $o->{c} = substr($nconf, $i, 1);
         $o->{pos}++;
 
+        if ($c ne '/') {
+            $o->{was_asterisk} = undef;
+        }
+
         if ($c eq '{') {
             next if ($o->{mode} == $LINE_COMMENT) or ($o->{mode} == $BLOCK_COMMENT);
 
@@ -254,7 +258,7 @@ sub parse {
             end_of_value($o);
             end_of_param($o);
 
-            if (scalar(@{$o->{context}}) == 0) {
+            if (scalar(@{$o->{context}}) == 1) {
                 die "Unmatched closing bracket at config line $line position $o->{pos}";
             }
             pop @{$o->{context}};
@@ -382,6 +386,8 @@ sub parse {
 
     die "Unmatched backtick at config line $line position $o->{pos}" if $in_raw_mode;
 
+    die "Missing closing bracket at config line $line position $o->{pos}" if @{$o->{context}} > 1;
+
     end_of_value($o);
     end_of_param($o);
 
